// ignore_for_file:implementation_imports
import 'package:intl/src/intl_helpers.dart';

import 'service/labels_service.dart';
import 'proxy/proxy.dart';
import 'model/release_data.dart';
import 'model/translations_update_result.dart';
import 'store/store.dart';
import 'util/util.dart';
import 'sdk_data.dart';
import 'sdk_exception.dart';

class Localizely {
  static String _sdkToken;
  static String _distributionId;
  static bool _preRelease;

  Localizely._();

  static void init(String sdkToken, String distributionId) {
    _sdkToken = sdkToken;
    _distributionId = distributionId;

    messageLookup = MessageLookupProxy.from(messageLookup);
  }

  static void setPreRelease(bool preRelease) {
    _preRelease = preRelease;
  }

  static void setMetadata(Map<String, List<String>> metadata) {
    SdkData.metadata = metadata;
  }

  static bool hasMetadata() {
    return SdkData.metadata != null;
  }

  static Future<TranslationsUpdateResult> updateTranslations() async {
    if (_sdkToken == null) {
      throw SdkException(
          "Localizely SDK has not been initialized or SDK token has not been provided during SDK initialization.");
    }

    if (_distributionId == null) {
      throw SdkException(
          "Localizely SDK has not been initialized or distribution ID has not been provided during SDK initialization.");
    }

    if (SdkData.metadata == null) {
      throw SdkException(
          "Metadata configuration has not been set, please ensure 'ota_enabled' is set to 'true' within 'flutter_intl/localizely' section of the 'pubspec.yaml' file.");
    }

    var currentLocale = Util.getCurrentLocale();
    var deviceLocale = Util.getDeviceLocale();
    var appInstallationId = await Store.getAppInstallationId();
    var sdkBuildNumber = Util.getSdkBuildNumber();
    var appBuildNumber = await Util.getAppBuildNumber();
    var currentReleaseVersion = SdkData.releaseVersion;

    var releaseData = await LabelsService.getLabels(
        _sdkToken, _distributionId, currentLocale, appInstallationId, sdkBuildNumber, appBuildNumber,
        deviceLocale: deviceLocale, preRelease: _preRelease, releaseVersion: currentReleaseVersion);

    var newReleaseVersion = releaseData.version;

    _updateSdkData(releaseData);

    return TranslationsUpdateResult(currentReleaseVersion, newReleaseVersion);
  }

  static void _updateSdkData(ReleaseData releaseData) {
    SdkData.releaseData = releaseData;
  }
}
