import 'dart:io';
import 'dart:convert' as convert;

import 'package:uuid/uuid.dart';
import 'package:intl/intl.dart';
import 'package:package_info/package_info.dart';
import 'package:logger/logger.dart';

class Util {
  static final Logger _logger = Logger();

  static final String _sdkBuildNumber = '1.1.0';

  Util._();

  static String generateUuid() {
    return Uuid().v4();
  }

  static String canonicalizedLocale(String locale) {
    return Intl.canonicalizedLocale(locale);
  }

  static Future<String> getAppBuildNumber() async {
    var packageInfo = await PackageInfo.fromPlatform();
    return packageInfo.version;
  }

  static String getSdkBuildNumber() {
    return _sdkBuildNumber; // TODO: try to read and set this info from pubspec.yaml during build
  }

  static String getCurrentLocale() {
    return Intl.getCurrentLocale();
  }

  static String getDeviceLocale() {
    var deviceLocale;
    try {
      deviceLocale = canonicalizedLocale(Platform.localeName);
    } catch (e) {
      _logger.e('Failed to detect device locale', e);
    }

    return deviceLocale;
  }

  /// Convert to inline json message.
  static String formatJsonMessage(String jsonMessage) {
    try {
      var decoded = convert.jsonDecode(jsonMessage);
      return convert.jsonEncode(decoded);
    } catch (e) {
      return jsonMessage;
    }
  }
}
